﻿;******************************************************************************
;	カラープロファイル選択ツール
;
;	By NightWotk
;******************************************************************************

;******************************************************************************
; 起動と終了
;******************************************************************************
;------------------------------------------------------------------------------
; Autoexec
;------------------------------------------------------------------------------
	;環境設定
	#Persistent			;常駐
	#NoEnv				;環境変数無視
	#NoTrayIcon 			;トレイアイコン非表示起動
	#SingleInstance Force		;多重起動禁止
	SetWorkingDir,	%A_ScriptDir%	;作業ディレクトリ変更
	OnExit,	EndProcessing		;終了処理


	;定数用変数
	;ソフト情報設定
	APP_TILTE	:= "ColorProfileSelecter"			;タイトル
	APP_VER		:= "20250101"					;バージョン
	APP_WINDOWTITLE	:= APP_TILTE . " (Ver." . APP_VER . ")"		;ウィンドウタイトル


	;Iniファイル関係
	INI_FILENAME		:= "Config.ini"				;ファイル名
	INI_SECTION		:= "Config"				;セクション名(一般設定)
	INI_SECTION_SSTP	:= "SSTP"				;セクション名(SSTP)
	LoadConfig()

	;SSTP拡張 ファイルチェック
	IfExist, sstpcmdR.exe
		sstp_enable	:= 1
	Else
		sstp_enable	:= 0

	;デバッグ用ウィンドウ初期化
	DebugWindow_Init()

	;トレイアイコンメニュー初期化
	TrayMenu_Init()

	;トレイアイコン表示
	Menu, Tray, Icon

	;ListVars

	Return



;------------------------------------------------------------------------------
; 共通関数ライブラリ読込
;------------------------------------------------------------------------------
#Include Libs\functions.ahk



;------------------------------------------------------------------------------
; 終了処理
;------------------------------------------------------------------------------
EndProcessing:
	ExitApp		;本終了
	Return



;------------------------------------------------------------------------------
; 設定ファイル読込
;------------------------------------------------------------------------------
LoadConfig(){
	global

	;一般設定
	;トレイアイコンファイル
	IniRead	, app_iconfile		, %INI_FILENAME%, %INI_SECTION%	, IconFile
		, C:\Windows\System32\colorcpl.exe

	;トレイアイコンインデックス
	IniRead	, app_iconindex		, %INI_FILENAME%, %INI_SECTION%	, IconIndex
		, 0

	;システムスコープで登録する
	IniRead	, systemscope		, %INI_FILENAME%, %INI_SECTION%	, SetSystemScope
		, 0

	;ダブルクリック切替のデフォルトディスプレイ
	IniRead	, defaultdisplay	, %INI_FILENAME%, %INI_SECTION%	, DefaultDisplay
		, 1

	;通知設定
	IniRead	, notify_enable		, %INI_FILENAME%, %INI_SECTION%, NotifyEnable
		, 0

	;通知音設定
	IniRead	, notifysound_enable	, %INI_FILENAME%, %INI_SECTION%, NotifySoundEnable
		, 0


	;SSTP関連
	;SSTP通知設定
	IniRead	, sstp_notify_enable	, %INI_FILENAME%, %INI_SECTION_SSTP%, Enable
		, 1

	;SSTP送信先Host
	IniRead	, sstp_notify_host	, %INI_FILENAME%, %INI_SECTION_SSTP%, Host
		, 127.0.0.1

	;SSTP送信先Port
	IniRead	, sstp_notify_port	, %INI_FILENAME%, %INI_SECTION_SSTP%, Port
		, 9801
}


;******************************************************************************
; デバッグウィンドウ周り
;******************************************************************************
;------------------------------------------------------------------------------
; デバッグウィンドウ初期化
;------------------------------------------------------------------------------
DebugWindow_Init(){
	;変数初期化
	global		;【グローバル変数モード】

	;配置パラメータ(個別でローカル変数とする)
	local GUI_CONTROL_PITCH_X		:= 10
	local GUI_CONTROL_PITCH_Y		:= -3
	local GUI_CONTROL_WIDTH_LABEL		:= 150
	local GUI_CONTROL_WIDTH_CONFIG		:= 80
	local GUI_CONTROL_HIGHT			:= 20


	Gui, Add, Text	, xm ym w%GUI_CONTROL_WIDTH_LABEL% h%GUI_CONTROL_HIGHT%
			, アプリケーションウィンドウハンドル

	Gui, Add, Edit	, x+%GUI_CONTROL_PITCH_X% yp%GUI_CONTROL_PITCH_Y% w%GUI_CONTROL_WIDTH_CONFIG% h%GUI_CONTROL_HIGHT% ReadOnly vCtrlEdit_App_hWnd
			, 0

	;自身のhWndを取得
	Gui, +LastFound
	WinGet, app_hwnd, ID
	GuiControl	, Text	, CtrlEdit_App_hWnd	, %app_hwnd%

	;ウィンドウ仮表示
	Gui, Show, Hide, %APP_WINDOWTITLE%

	;ウィンドウサイズ取得
	WinGetPos,,, app_windwow_w, app_windwow_h
	Return
}



;******************************************************************************
; トレイアイコンメニュー
;******************************************************************************
;------------------------------------------------------------------------------
; トレイアイコンメニュー 初期化
;------------------------------------------------------------------------------
TrayMenu_Init(){
	;変数初期化
	global					;【グローバル変数モード】

	;初期設定
	Menu, Tray, Tip, %APP_TILTE%				;タイトル設定(仮)

	;トレイアイコン変更
	If ( FileExist( app_iconfile ) )
		Menu, Tray, Icon, %app_iconfile%, %app_iconindex%

	Menu, Tray, NoStandard					;標準項目抹消
	Menu, Tray, UseErrorLevel				;エラーダイアログOFF

	TrayMenu_Update()
	Return
}


;------------------------------------------------------------------------------
; トレイアイコンメニュー 再構築
; 最新の情報取得もここで行う
; notify	指定されたディスプレイ番号の現在のプロファイルを通知する(0で通知なし)
;------------------------------------------------------------------------------
TrayMenu_Update(notify=0){
	;変数初期化
	global					;【グローバル変数モード】
	local menuitem_name		:= ""	;メニュー項目名
	local display_index		:= 0	;処理中のディスプレイ番号
	local profile_index		:= 0	;処理中のプロファイル番号
	local profile_index_max		:= 0	;各ディスプレイのプロファイル数
	local profile_index_next	:= 0	;次のプロファイル番号（ダブルクリックでの切替対象）
	local notify_text		:= ""	;通知テキスト
	local notifysound_file		:= ""	;通知音ファイル


	;データ更新
	GetDisplayList()			;ディスプレイ一覧更新
	GetProfileList()			;プロファイル一覧更新
	GetDefaultColorProfile()		;既定のプロファイル情報取得
	DefaultDisplaySelectMenu_Update()	;デフォルトディスプレイ

	;毒電波送信
	If ( sstp_enable && sstp_notify_enable )
		SSTP_OnColorProfileUpDate(notify)

	;通知機能
	If ( notify )
	{
		;トースト通知
		If ( notify_enable )
		{
			notify_text	:= "ディスプレイ:" . notify . "`n" .  display_%notify%_profile
			TrayTip, %APP_TILTE%, %notify_text%, 1, 17
		}

		;通知音再生
		If ( notifysound_enable )
		{
			;レジストリから通知音を取得
			RegRead, notifysound_file, HKEY_CURRENT_USER, AppEvents\Schemes\Apps\.Default\Notification.Default\.Current

			;ファイル存在チェックして鳴らす
			IfExist, %notifysound_file%
				SoundPlay, %notifysound_file%
		}
	}


	;既存項目全削除
	Menu, Tray, DeleteAll			;メニュー内全項目を抹消


	;メニュー項目作成------------------------------
	;ディスプレイが存在しない場合
	If( !display_index_max )
	{
		menuitem_name	:= "ディスプレイが存在しません"
		Menu, Tray, Add		, %menuitem_name%	, TrayMenu_Dummy
		Menu, Tray, Disable	, %menuitem_name%
		Menu, Tray, Add
	}

	;ディスプレイ一覧ループ
	Loop, %display_index_max%
	{
		;処理中のディスプレイ番号を控える
		display_index	:= A_Index

		;ディスプレイラベル項目(現在のスコープも表示)
		menuitem_name	:= display_index . ":" . display_%display_index%_name . "[" . display_%display_index%_profile_scope . "]"
		Menu, Tray, Add		, %menuitem_name%	, TrayMenu_Dummy
		Menu, Tray, Disable	, %menuitem_name%


		;登録されているプロファイル数を取得
		profile_index_max	:= display_%display_index%_profile_max

		;プロファイルが存在しない場合
		If( !profile_index_max )
		{
			menuitem_name	:= "プロファイルが存在しません"
			Menu, Tray, Add		, %menuitem_name%	, TrayMenu_Dummy
			Menu, Tray, Disable	, %menuitem_name%
		}

		;登録されているプロファイル一覧ループ
		Loop, %profile_index_max%
		{
			;処理中のプロファイル番号を控える
			profile_index	:= A_Index

			;プロファイル名追加
			menuitem_name	:= display_index . "-" . profile_index . ":" . display_%display_index%_profile_%profile_index%
			Menu, Tray, Add		, %menuitem_name%	, TrayMenu_SelectProfile

			;現在値ならチェックを入れ、ダブルクリック切替用プロファイル番号を計算する。
			If ( display_%display_index%_profile_%profile_index% == display_%display_index%_profile )
			{
				Menu, Tray, Check, %menuitem_name%
				profile_index_next	:= Mod(( profile_index ), profile_index_max) + 1
			}
		}

		;プロファイルが二つ以上ある場合ダブルクリックで切替できるようにする
		If (( display_index == defaultdisplay ) && ( profile_index_max > 1 ))
		{
			;次のプロファイルをデフォルトにする
			menuitem_name	:= display_index . "-" . profile_index_next . ":" . display_%display_index%_profile_%profile_index_next%
			Menu, Tray, Default, %menuitem_name%
		}

		Menu, Tray, Add
	}

	;デフォルトディスプレイ選択
	Menu, Tray, Add , ダブルクリック切替対象ディスプレイ, :DefaultDisplaySelect

	;スコープ切替
	Menu, Tray, Add	, システムの規定値として設定する	, TrayMenu_SwitchScope
	If ( systemscope )
		Menu, Tray, Check, システムの規定値として設定する

	Menu, Tray, Add


	;通知設定
	Menu, Tray, Add		, 切替時に通知を表示			, TrayMenu_Notify_Switch		;通知有効・無効切替
	If ( notify_enable )
		Menu, Tray, Check, 切替時に通知を表示


	Menu, Tray, Add		, 切替時に通知音を鳴らす		, TrayMenu_NotifySound_Switch		;通知音声有効・無効切替
	If ( notifysound_enable )
		Menu, Tray, Check, 切替時に通知音を鳴らす


	;SSTP通知切替(追加ファイルがインストールされている場合のみ表示)
	If ( sstp_enable )
	{
		Menu, Tray, Add		, 切替時にSSTPを送信		, TrayMenu_SSTP_Notify_Switch	;通知音声有効・無効切替
		If ( sstp_notify_enable )
			Menu, Tray, Check, 切替時にSSTPを送信
	}

	Menu, Tray, Add

	;その他
	Menu, Tray, Add , 最新の情報に更新	, TrayMenu_Refresh	;最新の情報に更新
	Menu, Tray, Add , リロード		, TrayMenu_Reload	;再起動
	Menu, Tray, Add , 終了			, TrayMenu_End		;終了

	Return
}


;------------------------------------------------------------------------------
; トレイアイコンメニューからの操作
;------------------------------------------------------------------------------
;ダミー(ラベル割り当てなしの場合メニューが表示されない)
TrayMenu_Dummy:
	Return

;プロファイル切替
TrayMenu_SelectProfile:
	SetDefaultColorProfile( A_ThisMenuItem )
	Return

;最新の情報に更新(メニュー再構築)
TrayMenu_Refresh:
	TrayMenu_Update()
	Return

;システムスコープモード切替
TrayMenu_SwitchScope:
	systemscope	:= Mod(systemscope+1,2)
	IniWrite, %systemscope%		, %INI_FILENAME%, %INI_SECTION%	, SetSystemScope
	TrayMenu_Update()
	Return

;通知有効・無効切替
TrayMenu_Notify_Switch:
	notify_enable	:= Mod(notify_enable+1,2)
	IniWrite, %notify_enable%	, %INI_FILENAME%, %INI_SECTION%, NotifyEnable
	TrayMenu_Update()
	Return

;通知音有効・無効切替
TrayMenu_NotifySound_Switch:
	notifysound_enable	:= Mod(notifysound_enable+1,2)
	IniWrite, %notifysound_enable%	, %INI_FILENAME%, %INI_SECTION%, NotifySoundEnable
	TrayMenu_Update()
	Return

;SSTP通知有効・無効切替
TrayMenu_SSTP_Notify_Switch:
	sstp_notify_enable	:= Mod(sstp_notify_enable+1,2)
	IniWrite, %sstp_notify_enable%	, %INI_FILENAME%, %INI_SECTION_SSTP%, Enable
	TrayMenu_Update()
	Return

;再起動
TrayMenu_Reload:
	Reload
	Return

;終了
TrayMenu_End:
	ExitApp		;終了処理へ移行
	Return



;******************************************************************************
; デフォルトディスプレイメニュー
; トレイアイコンダブルクリック時にプロファイルを切り替えるディスプレイ
;******************************************************************************
;------------------------------------------------------------------------------
; デフォルトディスプレイ選択メニュー作成・更新
;------------------------------------------------------------------------------
DefaultDisplaySelectMenu_Update(){
	;変数初期化
	global		;【グローバル変数モード】
	local menu_name		:= "DefaultDisplaySelect"	;メニュー名
	local menuitem_name	:= ""				;メニュー項目名
	local display_index	:= 0	;処理中のディスプレイ番号


	;既存項目全削除
	Menu, %menu_name%, DeleteAll		;メニュー内全項目を抹消


	;メニュー項目作成------------------------------
	;ディスプレイが存在しない場合
	If( !display_index_max )
	{
		menuitem_name	:= "ディスプレイが存在しません"
		Menu, %menu_name%, Add		, %menuitem_name%	, TrayMenu_Dummy
		Menu, %menu_name%, Disable	, %menuitem_name%
		Return
	}

	;ディスプレイ一覧ループ
	Loop, %display_index_max%
	{
		;処理中のディスプレイ番号を控える
		display_index	:= A_Index

		;ディスプレイ項目
		menuitem_name	:= display_index . ":" . display_%display_index%_name
		Menu, %menu_name%, Add		, %menuitem_name%	, DefaultDisplaySelectMenu_SelectDefaultDisplay

		;設定値ならチェックを入れる
		If ( display_index == defaultdisplay )
			Menu, %menu_name%, Check, %menuitem_name%
	}

	Return
}


;------------------------------------------------------------------------------
; DDSメニューからの操作
;------------------------------------------------------------------------------
;デフォルトディスプレイ切替
DefaultDisplaySelectMenu_SelectDefaultDisplay:
	SelectDefaultDisplay(A_ThisMenuItem)
	Return


;------------------------------------------------------------------------------
; デフォルトディスプレイを変更
;
; menuitem	メニュー項目名が飛んでくる。「(ディスプレイ番号):ディスプレイ名」
;------------------------------------------------------------------------------
SelectDefaultDisplay(menuitem){
	;変数初期化
	global

	local display_index	:= 0		;ディスプレイ番号
	local display_index_pos	:= 0		;ディスプレイ番号開始位置
	local display_index_len	:= 0		;ディスプレイ番号文字数


	;選択されたメニューラベルからディスプレイ番号を抽出
	;文字位置検索
	display_index_pos	:= 0
	display_index_len	:= FxStringGetPos( menuitem, ":")

	;データ取得
	display_index		:= FxStringLeft( menuitem, display_index_len)				;ディスプレイ番号取得

	;デフォルトディスプレイにセット
	defaultdisplay	:= display_index

	;設定ファイルに保存
	IniWrite, %defaultdisplay%	, %INI_FILENAME%, %INI_SECTION%	, DefaultDisplay

	;トレイアイコンメニュー更新
	TrayMenu_Update()

	Return
}



;******************************************************************************
; プロファイル関係外部アプリ処理
;******************************************************************************
;------------------------------------------------------------------------------
; ディスプレイの一覧を取得
;------------------------------------------------------------------------------
GetDisplayList(){
	;変数初期化
	global	;ディスプレイ数に応じてグローバル変数を作る為デフォルトグローバル

	local display_index	:= 0	;ディスプレイ番号
	display_index_max	:= 0	;ディスプレイ数(リセット)

	;バッチファイル系定数・変数
	local BATCH_FILE	:= "Core\GetDisplayNames.bat"		;実行するバッチファイル名
	local BATCH_RESULT_FILE	:= "Core\GetDisplayNamesResult.log"	;結果ファイル
	local result		:= ""					;コマンド実行結果


	;バッチファイル実行
	RunWait, %BATCH_FILE%,, Hide UseErrorLevel
	If ( ErrorLevel == "ERROR" )
	{
		MsgBox , 16, エラー, 「%BATCH_FILE%」起動エラー。
		Return
	}

	;結果読み込み
	FileRead, result, *t %BATCH_RESULT_FILE%
	If ( ErrorLevel )
	{
		MsgBox , 16, エラー, 「%BATCH_RESULT_FILE%」読込失敗。
		Return
	}

	;一時ファイル削除
	FileDelete	, %BATCH_RESULT_FILE%

	;ディスプレイが存在しない場合
	If ( result == "")
		Return

	;読込内容を各行ループしてディスプレイ名一覧を作る
	Loop, Parse, result, `n
	{
		;ディスプレイ番号
		display_index	:= A_Index

		;コマンド実行結果エラーチェック
		If ( display_index == 1
		&& FxStringLeft( A_LoopField, 6 ) == "ERROR:" )
		{
			MsgBox , 16, エラー, 「%BATCH_FILE%」実行エラー。
			Return
		}

		;ディスプレイ名
		display_%display_index%_name	:= FxStringTrimLeft( A_LoopField, FxStringLen("\\.\DISPLEY" . display_index . ":"))

		;ディスプレイ数
		display_index_max		:= display_index - 1
	}

	Return
}



;------------------------------------------------------------------------------
; ディスプレイプロファイルの一覧を取得
; システムスコープ・ユーザースコープを両方まとめる
;------------------------------------------------------------------------------
GetProfileList(){
	;変数初期化
	global

	local display_index	:= 0		;ディスプレイ番号
	local profile_index	:= 0		;プロファイル番号
	local profile_index_max	:= 0		;プロファイル数

	local profilelist	:= ""		;プロファイルリスト

	;バッチファイル系定数・変数
	local BATCH_FILE	:= "Core\GetColorProfiles.bat"		;実行するバッチファイル名
	local BATCH_RESULT_FILE	:= "Core\GetColorProfilesResult.log"	;結果ファイル
	local result		:= ""					;コマンド実行結果


	;ディスプレイ数ループ
	Loop, %display_index_max%
	{
		;ディスプレイ番号
		display_index	:= A_Index

		;プロファイル数を初期化
		display_%display_index%_profile_max	:= 0

		;バッチファイル実行
		RunWait, %BATCH_FILE% \\.\DISPLAY%display_index% /A,, Hide UseErrorLevel
		If ( ErrorLevel == "ERROR" )
		{
			MsgBox , 16, エラー, 「%BATCH_FILE%」起動エラー。
			Return
		}

		;結果読み込み
		FileRead, result, *t %BATCH_RESULT_FILE%
		If ( ErrorLevel )
		{
			MsgBox , 16, エラー, 「%BATCH_RESULT_FILE%」読込失敗。
			Return
		}

		;一時ファイル削除
		FileDelete	, %BATCH_RESULT_FILE%

		;読込内容を各行ループしてプロファイル名一覧を作る
		Loop, Parse, result, `n
		{
			;エラーチェック
			If (( A_Index == 1 )
			&& FxStringLeft( A_LoopField, 6 ) == "ERROR:" )
			{
				MsgBox , 16, エラー, 「%BATCH_FILE%」実行エラー。
				Return
			}

			;ヘッダ読み飛ばし
			If ( A_Index < 4 )
				Continue

			;リストに追加
			profilelist	:= profilelist . A_LoopField . "`n"
		}

		;リストをソートして重複排除
		Sort, profilelist, R C U Z	;空行除去用
		Sort, profilelist, C		;昇順ソート

		;読込内容を各行ループしてディスプレイごとのプロファイル名一覧を作る
		Loop, Parse, profilelist, `n
		{
			;プロファイル番号
			profile_index	:= A_Index

			;プロファイル名
			display_%display_index%_profile_%profile_index%	:= A_LoopField

			;プロファイル数
			display_%display_index%_profile_max		:= profile_index - 1
		}
	}

	Return
}



;------------------------------------------------------------------------------
; 既定のディスプレイプロファイルとスコープの取得
;------------------------------------------------------------------------------
GetDefaultColorProfile(){
	;変数初期化
	global

	local display_index	:= 0	;ディスプレイ番号

	;バッチファイル系定数・変数
	local BATCH_FILE	:= "Core\GetDefaultColorProfile.bat"		;実行するバッチファイル名
	local BATCH_RESULT_FILE	:= "Core\GetDefaultColorProfileResult.log"	;結果ファイル
	local result		:= ""						;コマンド実行結果


	;ディスプレイ数ループ
	Loop, %display_index_max%
	{
		;処理中のディスプレイ番号を控える
		display_index	:= A_Index

		;バッチファイル実行
		RunWait, %BATCH_FILE% \\.\DISPLAY%display_index%,, Hide UseErrorLevel
		If ( ErrorLevel == "ERROR")
		{
			MsgBox , 16, エラー, 「%BATCH_FILE%」起動エラー。
			Return
		}

		;結果読み込み
		FileRead, result, *t %BATCH_RESULT_FILE%
		If ( ErrorLevel )
		{
			MsgBox , 16, エラー, 「%BATCH_RESULT_FILE%」読込失敗。
			Return
		}

		;一時ファイル削除
		FileDelete	, %BATCH_RESULT_FILE%

		;読込内容を各行ループ
		Loop, Parse, result, `n
		{
			;エラーチェック
			If (( A_Index == 1 )
			&& FxStringLeft( A_LoopField, 6) == "ERROR:" )
			{
				MsgBox , 16, エラー, 「%BATCH_FILE%」実行エラー。
				Return
			}

			;プロファイルスコープ
			If ( A_Index == 2 )
				display_%display_index%_profile_scope	:= FxStringTrimLeft( A_LoopField, 6 )

			;プロファイル名
			If ( A_Index == 3 )
				display_%display_index%_profile		:= FxStringTrimLeft( A_LoopField, 8 )
		}
	}

	Return
}



;------------------------------------------------------------------------------
; 既定のディスプレイプロファイルを変更
;
; menuitem	トレイメニュー項目名が飛んでくる。「(ディスプレイ番号)-(プロファイル番号)プロファイル名」
;------------------------------------------------------------------------------
SetDefaultColorProfile(menuitem){
	;変数初期化
	global

	local display_index	:= 0		;ディスプレイ番号
	local profile_index	:= 0		;プロファイル番号
	local display_index_pos	:= 0		;ディスプレイ番号開始位置
	local display_index_len	:= 0		;ディスプレイ番号文字数
	local profile_index_pos	:= 0		;プロファイル番号開始位置
	local profile_index_len := 0		;プロファイル番号文字数
	local profile_name	:= ""		;プロファイル名

	;バッチファイル系定数・変数
	local BATCH_FILE	:= "Core\SetDefaultColorProfile.bat"		;実行するバッチファイル名
	local BATCH_RESULT_FILE	:= "Core\SetDefaultColorProfileResult.log"	;結果ファイル
	local result		:= ""						;コマンド実行結果


	;選択されたメニューラベルからディスプレイ番号とプロファイル番号を抽出し、プロファイル名を取得する。
	;文字位置検索
	display_index_pos	:= 0
	display_index_len	:= FxStringGetPos( menuitem, "-")
	profile_index_pos	:= display_index_len + 1
	profile_index_len	:= FxStringGetPos( menuitem, ":") - profile_index_pos

	;データ取得
	display_index		:= FxStringLeft( menuitem, display_index_len)				;ディスプレイ番号取得
	profile_index		:= FxStringMid( menuitem, profile_index_pos + 1, profile_index_len)	;プロファイル番号取得
	profile_name		:= display_%display_index%_profile_%profile_index%			;プロファイル名取得(ラベルではなく変数から持ってくる)


	;バッチファイル実行
	If ( systemscope )
		RunWait, %BATCH_FILE% \\.\DISPLAY%display_index% "%profile_name%" /S,, Hide UseErrorLevel	;システムスコープモード
	Else
		RunWait, %BATCH_FILE% \\.\DISPLAY%display_index% "%profile_name%",, Hide UseErrorLevel		;ユーザースコープモード
	If ( ErrorLevel == "ERROR")
	{
		MsgBox , 16, エラー, 「%BATCH_FILE%」起動エラー。
		TrayMenu_Update()
		Return
	}

	;結果読み込み
	FileReadLine, result, %BATCH_RESULT_FILE%, 1
	If ( ErrorLevel )
	{
		MsgBox , 16, エラー, 「%BATCH_RESULT_FILE%」読込失敗。
		TrayMenu_Update()
		Return
	}

	;一時ファイル削除
	FileDelete	, %BATCH_RESULT_FILE%

	;エラーチェックだけする（結果取得はメニュー再構築で行う）
	;想定される要因はディスプレイ情報が古い、指定されたプロファイルが存在しない等
	If ( FxStringLeft( result, 6 ) == "ERROR:" )
	{
		MsgBox , 16, エラー, 「%BATCH_FILE%」実行結果エラー`nもう一度やり直してください。
		TrayMenu_Update()
		Return
	}

	;トレイアイコンメニュー更新(通知もあちらで行う)
	TrayMenu_Update(display_index)

	Return
}



;******************************************************************************
; SSTP 関連
;******************************************************************************
;------------------------------------------------------------------------------
; プロファイル通知
;------------------------------------------------------------------------------
;	Sender		"ColorProfileSelecter"
;	ShioriEVENTID	OnColorProfileUpDate
;	Reference0	通知するディスプレイ番号(0:通知なし)
;	Reference1	ディスプレイ1のプロファイル名
;	Reference2	ディスプレイ2のプロファイル名(以下ディスプレイ数だけ続く、最大15)
;
;------------------------------------------------------------------------------
SSTP_OnColorProfileUpDate(reason){
	;変数初期化
	global		;【グローバル変数モード】
	local display_index		:= 0	;処理中のディスプレイ番号
	local profile_name		:= 0	;処理中ディスプレイのプロファイル名

	local cmd_option			;コマンドラインバッファ

	;SSTPヘッダ
	local sender	:= APP_TILTE
	local eventid	:= "OnColorProfileUpDate"

	;通知ディスプレイ番号
	cmd_option	:= "-0" . reason

	;ディスプレイ一覧ループ
	Loop, %display_index_max%
	{
		;処理中のディスプレイ番号を控える
		display_index	:= A_Index

		;最大数リミッタ
		If display_index > 15
			Break

		;プロファイル名取得
		profile_name	:= display_%display_index%_profile

		;コマンドラインに追加
		cmd_option	:= cmd_option . " -" . display_index . Chr(0x22) . profile_name . Chr(0x22)
	}

	;実行ファイルチェックと実行
	IfExist, sstpcmdR.exe
		Run, sstpcmdR.exe -h"%sstp_notify_host%" -p"%sstp_notify_port%" -s"%sender%" -i"%eventid%" %cmd_option%,, Hide UseErrorLevel

	Return
}
